<!DOCTYPE style-sheet PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN" [
<!--
    PUBLIC "-//Free Text Project//DOCUMENT Testament DSSSL Style Sheet//EN"

    Version: 97-01-01 12:40
    font-weight 'normal changed to 'medium 97.03.06 jb 

    Command Line Options: "-V fm" - display front matter (default is to hide)

    This style sheet is used to print testaments marked up according to the
    "DTD for testaments" by Jon Bosak dated 940401.  The style sheet was
    written by an Anonymous Contributor.

    Syntax conventions: *manifest* - variable/procedure bound at the top level
-->
]>

;**********************************************
; command line triggers

(define FM          #f)         ;flag indicating generation of front matter
(define fm          #f)
(define *fm*        (or FM fm))

;**********************************************
; manifests and other initial and default conditions


(define *titleFontFamily*       "Times New Roman")
(define *titleFontSize*         18pt)
(define *title2FontSize*        16pt)
(define *title2Indent*          1in)
(define *titlePrefFontSize*     14pt)
(define *titlePrefaceIndent*    1in)

(define *frontMatterIndent*     .25in)

(define *bookFontFamily*        "Times New Roman")
(define *bookFontSize*          14pt)
(define *bookSumIndent*         .5in)
(define *chapSumIndent*         1in)

(define *textFontFamily*        "Times New Roman")
(define *textFontSize*          12pt)
(define *verseNumberFontSize*   8pt)
(define *verseIndent*           .25in)

(declare-initial-value  font-family-name    *textFontFamily*)
(declare-initial-value  font-size           *textFontSize*)
(declare-initial-value  line-spacing        *textFontSize*)

(define *pageStyle*             ;used whenever a page set starts
    (style
        left-margin:    1in
        right-margin:   1in
        top-margin:     1in
        bottom-margin:  1in
        footer-margin:  .5in))
    
; no default behaviour allowed to ensure nothing is missed
; (the following requires all elements to have explicit construction rules)
(default (error (string-append "No construction rule for element: '"
                               (gi (current-node))
                               "'")))

;**********************************************
; Title and other front matter

(element TSTMT      ;the entire testament
        (process-children))

(element TTITLE                 ;testament title
    (make simple-page-sequence  ;the first data establishes page parms
        use:                    *pageStyle*
        center-footer:          (page-number-sosofo)
        (make paragraph
            quadding:           'center
            font-family-name:   *titleFontFamily*
            font-size:          *titleFontSize*
            line-spacing:       *titleFontSize*
            font-weight:        'bold
            (process-children-trim))))

(element TTITLE2                ;testament long title
    (make paragraph
        quadding:               'center
        font-family-name:       *titleFontFamily*
        font-size:              *title2FontSize*
        line-spacing:           *title2FontSize*
        font-weight:            'medium
        start-indent:           *title2Indent*
        end-indent:             *title2Indent*
        (process-children-trim)))

(element FM                     ;front matter
    (if *fm*                    ;parameterized display
        (make box               ;requested to display
            display?:           #t
            start-indent:       *frontMatterIndent*
            end-indent:         *frontMatterIndent*
            space-before:       *titleFontSize*
            (process-children))
        (empty-sosofo)))        ;requested to not display

(element (FM P)                 ;paragraphs in front matter
    (make paragraph
        space-before:           *textFontSize*
        (process-children)))

(element SBTTITLE               ;testament subtitle
    (make paragraph
        (process-children)))

(element (SBTTITLE P)           ;paragraphs in testament subtitle
    (make paragraph
        first-line-start-indent: *verseIndent*
        space-before:           *textFontSize*
        (process-children)))

(element PREFACE                ;testament preface
    (sosofo-append
        (process-children)      ;put out all paragraphs
        (make paragraph         ;blank line following all paragraphs
            (literal ""))))

(element PTITLE                 ;preface title
    (make paragraph
        quadding:               'center
        font-family-name:       *titleFontFamily*
        font-size:              *titlePrefFontSize*
        line-spacing:           *titlePrefFontSize*
        font-weight:            'medium
        start-indent:           *titlePrefaceIndent*
        end-indent:             *titlePrefaceIndent*
        space-before:           *titlePrefFontSize*
        space-after:            *titlePrefFontSize*
        keep-with-next?:        #t
        (process-children-trim)))

(element (PREFACE P)            ;paragraphs in preface
    (make paragraph
        first-line-start-indent: *verseIndent*
        (process-children)))

;**********************************************
; Book Information

(define (*bookChapTitleSosofo*) ;combine current book with current chapter
    (sosofo-append
        (literal (data (select-elements (children (if (equal? (gi) "BOOK")
                                                      (current-node)
                                                      (ancestor "BOOK")))
                                        '(BKTSHORT))))
        (literal " - ")
        (literal (data (select-elements (children (if (equal? (gi) "CHAPTER")
                                                      (current-node)
                                                      (ancestor "CHAPTER")))
                                        '(CHTITLE))))))

(element BOOK
    (make simple-page-sequence  ;start each book on a new page
        use:                    *pageStyle*
        center-footer:          (page-number-sosofo)
;       left-footer:            (*bookChapTitleSosofo*) ;disabled for now
        (process-children)))

(element SURA                   ;so many books, no need to start on new page
    (sosofo-append
        (make paragraph         ;blank line preceeding book
            (literal ""))   
        (process-children)))    ;put out all content

(element BKTLONG                ;book title in long form
    (make paragraph
        quadding:               'center
        font-family-name:       *bookFontFamily*
        font-size:              *bookFontSize*
        font-weight:            'bold
        space-after:            *textFontSize*
        keep-with-next?:        #t
        (process-children-trim)))

(element BKTSHORT               ;book title in short form
    (empty-sosofo))             ;used only in chapter titles

(element BKSUM                  ;book summary
    (process-children))

(element (BKSUM P)              ;paragraphs in book summary
    (make paragraph
        first-line-start-indent: *verseIndent*
        start-indent:           *bookSumIndent*
        end-indent:             *bookSumIndent*
        font-posture:           'italic
        keep-with-next?:        #t
        (process-children-trim)))

(element EPIGRAPH               ;book epigraph
    (sosofo-append
        (process-children)      ;put out all paragraphs
        (make paragraph         ;blank line following all paragraphs
            keep-with-next?:    #t
            (literal ""))))

(element (EPIGRAPH P)           ;paragraphs in book epigraph
    (make paragraph
        quadding:               'center
        start-indent:           *bookSumIndent*
        end-indent:             *bookSumIndent*
        font-posture:           'italic
        keep-with-next?:        #t
        (process-children-trim)))

;**********************************************
; Chapter information

(element CHAPTER (process-children))

(define (*chTitleNeeded?*)      ;logic to determine need for a chapter title
    (if (= (child-number (parent)) 1)
        (if (node-list-empty?   ;check to see if there is a chapter summary
                (select-elements (children (ancestor "CHAPTER")) '(CHSUM)))
            #f                  ;not needed if there is no chapter summary
            #t)                 ;needed to separate chapter summary
        #t))                    ;always need it if not the first chapter

(element CHTITLE                ;chapter title in long form
    (if (*chTitleNeeded?*)
        (make paragraph         ;need the chapter title
            quadding:           'center
            font-family-name:   *bookFontFamily*
            font-size:          *bookFontSize*
            font-weight:        'bold
            space-before:       *textFontSize*
            space-after:        *textFontSize*
            keep-with-next?:    #t
            (*bookChapTitleSosofo*)) ;combine book and chapter title
        (empty-sosofo)))        ;don't need the chapter title

(element CHSUM                  ;chapter summary
    (sosofo-append
        (process-children)      ;put out all paragraphs
        (make paragraph         ;blank line following all paragraphs
            keep-with-next?:    #t
            (literal ""))))

(element (CHSUM P)              ;paragraphs in chapter summary
    (make paragraph
        first-line-start-indent: *verseIndent*
        start-indent:           *chapSumIndent*
        end-indent:             *chapSumIndent*
        font-posture:           'italic
        keep-with-next?:        #t          ;group chapter summary on page
        (process-children-trim)))

;**********************************************
; Verse information

(element V                      ;verse
    (make paragraph
        (process-children)))

(element VN                     ;verse number
    (make line-field
        field-width:            *verseIndent*
        field-align:            'end
        (make sequence
            font-size:          *verseNumberFontSize*
            font-posture:       'italic
            (process-children-trim))))

(element (V P)                  ;paragraph within a verse
    (make sequence
        (process-children-trim)))

(element I                      ;assumed to be italics within a paragraph
    (make sequence
        font-posture:           'italic
        (process-children-trim)))

; end of file

